@@ -1,4 +1,4 @@
-# Copyrights 2007-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@
 
 package Log::Report::Dispatcher::File;
 use vars '$VERSION';
-$VERSION = '1.28';
+$VERSION = '1.30';
 
 use base 'Log::Report::Dispatcher';
 
@@ -67,7 +67,7 @@ sub close()
       : $self->{LRDF_filename} ? $self->{LRDF_output}
       : ();
 
-    $_->close for @close;
+    $_ && $_->close for @close;
     $self;
 }
 
@@ -90,9 +90,20 @@ sub output($)
         $self->{LRDF_filename} = $to;
         my $binmode = $self->{replace} ? '>' : '>>';
 
-        my $f = $self->{LRDF_output} = IO::File->new($to, $binmode)
-            or fault __x"cannot write log into {file} with mode {binmode}"
+        my $f = $self->{LRDF_output} = IO::File->new($to, $binmode);
+        unless($f)
+        {   # avoid logging error to myself (issue #4)
+            my $msg  = __x"cannot write log into {file} with mode '{binmode}'"
                  , binmode => $binmode, file => $to;
+            if(my @disp = grep $_->name ne $name, Log::Report::dispatcher('list'))
+            {   $msg->to($disp[0]->name);
+                error $msg;
+            }
+            else
+            {   die $msg;
+            }
+        }
+
         $f->autoflush;
         return $self->{LRDF_output} = $f;
     }
