@@ -1,4 +1,4 @@
-# Copyrights 2007-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@
 
 package Log::Report::Dispatcher::Try;
 use vars '$VERSION';
-$VERSION = '1.28';
+$VERSION = '1.30';
 
 use base 'Log::Report::Dispatcher';
 
@@ -17,7 +17,7 @@ use strict;
 
 use Log::Report 'log-report', syntax => 'SHORT';
 use Log::Report::Exception ();
-use Log::Report::Util      qw/%reason_code/;
+use Log::Report::Util      qw/%reason_code expand_reasons/;
 use List::Util             qw/first/;
 
 
@@ -57,13 +57,8 @@ sub hides($)
 
 sub hide(@)
 {   my $self = shift;
-    my @h = map { ref $_ eq 'ARRAY' ? @$_ : defined($_) ? $_ : () } @_;
-
-    $self->{hides}
-      = @h==0 ? undef
-      : @h==1 && $h[0] eq 'ALL'  ? {}    # empty HASH = ALL
-      : @h==1 && $h[0] eq 'NONE' ? undef
-      :    +{ map +($_ => 1), @h };
+    my @reasons = expand_reasons(@_ > 1 ? \@_ : shift);
+    $self->{hides} = +{ map +($_ => 1), @reasons };
 }
 
 
