@@ -1,10 +1,10 @@
-# Copyrights 2007-2019 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2007-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
 package DieTests;
 use vars '$VERSION';
-$VERSION = '1.28';
+$VERSION = '1.30';
 
 use warnings;
 use strict;
@@ -13,7 +13,15 @@ use Log::Report::Die qw/die_decode/;
 use Log::Report      qw/log-report/;
 use Carp;
 
-use Test::More tests => 27;
+use Test::More;
+
+BEGIN {
+    plan skip_all => "Error messages on $^O differ too much."
+        if $^O =~ /haiku$/;
+
+    plan tests => 27;
+}
+
 use DieTests;
 
 $! = 3;
